@@ -8,7 +8,6 @@ describe 'trove::db' do
       it { should contain_oslo__db('trove_config').with(
         :connection              => 'sqlite:////var/lib/trove/trove.sqlite',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
@@ -22,7 +21,6 @@ describe 'trove::db' do
         {
           :database_connection              => 'mysql+pymysql://trove:trove@localhost/trove',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_max_pool_size           => '21',
           :database_max_retries             => '11',
           :database_max_overflow            => '21',
@@ -36,7 +34,6 @@ describe 'trove::db' do
       it { should contain_oslo__db('trove_config').with(
         :connection              => 'mysql+pymysql://trove:trove@localhost/trove',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '21',
         :max_retries             => '11',
         :retry_interval          => '11',
